Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(179)

Unified Diff: chrome/browser/ui/omnibox/omnibox_edit_model.h

Issue 11359198: Implement the Instant extended API startMargin, endMargin, and rtl properties and the onmarginchang… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/omnibox/omnibox_edit_model.h
diff --git a/chrome/browser/ui/omnibox/omnibox_edit_model.h b/chrome/browser/ui/omnibox/omnibox_edit_model.h
index c420ad45ab6dc6560ba9a55d49dd46f2c071dfc4..1ed200e3ba82ad4c5b9c23bc6ba321912087fbb8 100644
--- a/chrome/browser/ui/omnibox/omnibox_edit_model.h
+++ b/chrome/browser/ui/omnibox/omnibox_edit_model.h
@@ -273,8 +273,11 @@ class OmniboxEditModel : public AutocompleteControllerDelegate {
bool just_deleted_text,
bool allow_keyword_ui_change);
- // Invoked when the popup is going to change its bounds to |bounds|.
- void PopupBoundsChangedTo(const gfx::Rect& bounds);
+ // Invoked when the popup has changed its bounds to |bounds|.
+ void OnPopupBoundsChanged(const gfx::Rect& bounds);
+
+ // Invoked when the omnibox has changed its bounds to |bounds|.
+ void OnOmniboxBoundsChanged(const gfx::Rect& bounds);
private:
enum PasteState {

Powered by Google App Engine
This is Rietveld 408576698